// VERSION: 1.1.2
/* Utilities to make working with plain old C strings easier.
 *
 *
 * Copyright (c) 2021 nytpu <alex [at] nytpu.com>
 * SPDX-License-Identifier: BSL-1.0
 * The orginal source for this file is available at <https://git.sr.ht/~nytpu/libmisc>.
 *
 * Permission is hereby granted, free of charge, to any person or organization
 * obtaining a copy of the software and accompanying documentation covered by
 * this license (the "Software") to use, reproduce, display, distribute,
 * execute, and transmit the Software, and to prepare derivative works of the
 * Software, and to permit third-parties to whom the Software is furnished to
 * do so, all subject to the following:
 *
 * The copyright notices in the Software and this entire statement, including
 * the above license grant, this restriction and the following disclaimer, must
 * be included in all copies of the Software, in whole or in part, and all
 * derivative works of the Software, unless such copies or derivative works are
 * solely in the form of machine-executable object code generated by a source
 * language processor.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
 * SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
 * FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

#pragma once
#ifndef STRING_UTIL_H
#define STRING_UTIL_H

#include <stdbool.h>

// Ripped off from Plan 9 libc's seprint() function.
// Easily build up a string given a pointer, a pointer to the end of the
// string, and a format string + format specifiers to add.  Returns a pointer
// to the end of the new string, or returns end on the event of truncation.  It
// is safe to call seprintf when ptr == end, simply nothing will be written.
// On event of formatting failure, NULL is returned.
char *seprintf(char *ptr, char *end, const char *fmt, ...);

// Check if string starts with the given prefix
bool string_starts_with(const char *str, const char *prefix);

// Check if string ends with the given suffix
bool string_ends_with(const char *str, const char *suffix);

#endif // STRING_UTIL_H
